@@ -1,4 +1,6 @@
-from interop import InteropDataset, print_sample_dataset, InteropFileNotFoundError
+from interop import InteropDataset, print_sample_dataset 
+from exceptions import InteropFileNotFoundError
+from metadata import InteropMetadata
 from base_parser_class import InteropBinParser
 from tile_metrics import InteropTileMetrics
 from quality_metrics import InteropQualityMetrics
